# Rui Santos & Sara Santos - Random Nerd Tutorials
# Complete project details at https://RandomNerdTutorials.com/raspberry-pi-pico-w-micropython-ebook/
# Modified by Jim Hart 4/1/2024
# Original Author https://electrocredible.com/neopixel-micropython-raspberry-pi-pico-ws2812b/
# Modified by Jim Hart on April 16, 2024

import machine, onewire, ds18x20, time, neopixel  # Added neopixel from electrocredible
from machine import Pin


# Pin configuration for DS18B20 temperature sensor
ds_pin = machine.Pin(29)
ws_pin = 6 # This is the pin I have the signal line attached to
led_num = 24 # This is the number of LEDs on my NeoPixel Ring
BRIGHTNESS = 0.2  # Adjust the brightness (0.0 - 1.0)

# Create DS18X20 object using OneWire protocol with specified pin
ds_sensor = ds18x20.DS18X20(onewire.OneWire(ds_pin))

# Create an instance of the NeoPixel class called neoRing
neoRing = neopixel.NeoPixel(Pin(ws_pin), led_num)

def celsius_to_fahrenheit(temp_celsius):
    # Convert temperature from Celsius to Fahrenheit
    temp_fahrenheit = temp_celsius * (9/5) + 32 
    return temp_fahrenheit

def set_brightness(color):
    r, g, b = color
    r = int(r * BRIGHTNESS)
    g = int(g * BRIGHTNESS)
    b = int(b * BRIGHTNESS)
    return (r, g, b)

# Scan for DS18B20 sensors and print their ROM addresses
roms = ds_sensor.scan()
print('Found DS devices: ', roms)

while True:
    # Initiate temperature conversion for all sensors
    ds_sensor.convert_temp()
    time.sleep_ms(750)  # Wait for the conversion to complete (750 ms is recommended)

    for rom in roms:
        print(rom)

        # Read temperature in Celsius from the sensor
        tempC = ds_sensor.read_temp(rom)

        # Convert Celsius temperature to Fahrenheit
        tempF = celsius_to_fahrenheit(tempC)

        # Print the temperature readings
        print('temperature (ºC):', "{:.2f}".format(tempC))
        print('temperature (ºF):', "{:.2f}".format(tempF))
        print()

    time.sleep(5)  # Wait for 5 seconds before taking readings again
    # delay(1000);   # I put this in the loop because it was going too fast to observe
    if (tempF < 60): #{ # I selected this temperature since the ambient temperature is about 73 degrees
    # color(255,255,0); // turn the RGB LED blue  
    # delay(1000); // delay for 1 second 
    # Display blue
        color = (0, 0, 255)  # Blue color
        color = set_brightness(color)
        neoRing.fill(color)
        neoRing.write()
        time.sleep(1)    
    #}
    elif (tempF > 65 and tempF < 67): #{ # I selected these temperatures since they are in the middle
    # color(255,0,255); // turn the RGB LED green  
    # delay(1000); // delay for 1 second
    # Display green
        color = (0, 255, 0)  # Green color
        color = set_brightness(color)
        neoRing.fill(color)
        neoRing.write()
        time.sleep(1)
    #}
    elif (tempF > 67): #{ # I selected this temperature since it is below the temperature of my maximum 85 degrees
    # color(0,255,255); // turn the RGB LED red 
    # delay(1000); // delay for 1 second
    # Display red
        color = (255, 0, 0)  # Red color
        color = set_brightness(color)
        neoRing.fill(color)
        neoRing.write()
        time.sleep(1)
    #}